@@ -44,38 +44,27 @@ FieldTypes::FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connectio
     //the Gda::ValueType used by Glib::RefPtr<Gnome::Gda::Column>.
     //This first call to update_meta_store() is also necessary for other calls to get_meta_store_data() elsewhere to succeed.
     Glib::RefPtr<Gnome::Gda::DataModel> data_model_tables;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
     if(true) //Already done in ConnectionPool::connect(): gda_connection->update_meta_store())
+    {
       data_model_tables = gda_connection->get_meta_store_data(Gnome::Gda::CONNECTION_META_TYPES);
-#else
-    std::auto_ptr<Glib::Error> error;
-    if(true) //Already done in ConnectionPool::connect(): gda_connection->update_meta_store(error))
-      data_model_tables = gda_connection->get_meta_store_data(Gnome::Gda::CONNECTION_META_TYPES, error);
-
-    // Ignore error here, we do not process data_model_tables if it is NULL
-    // anyway
-#endif // GLIBMM_EXCEPTIONS_ENABLED
+    }
 
     if(!data_model_tables)
-      std::cerr << "FieldTypes::FieldTypes(): Couldn't get datamodel" << std::endl;
+      std::cerr << G_STRFUNC << ": Couldn't get datamodel" << std::endl;
 
     if(data_model_tables && (data_model_tables->get_n_columns() == 0))
     {
-      std::cerr << "FieldTypes::FieldTypes(): get_meta_store_data(Gnome::Gda::CONNECTION_META_TYPES) failed." << std::endl;
+      std::cerr << G_STRFUNC << ": get_meta_store_data(Gnome::Gda::CONNECTION_META_TYPES) failed." << std::endl;
     }
     else if(data_model_tables)
     {
-      int rows = data_model_tables->get_n_rows();
+      const int rows = data_model_tables->get_n_rows();
       if(!rows)
-        std::cerr << "FieldTypes::FieldTypes(): no rows from CONNECTION_META_TYPES" << std::endl;
+        std::cerr << G_STRFUNC << ": no rows from CONNECTION_META_TYPES" << std::endl;
 
       for(int i = 0; i < rows; ++i)
       {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
         const Gnome::Gda::Value value_name = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_NAME, i);
-#else
-        const Gnome::Gda::Value value_name = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_NAME, i, error);
-#endif
 
         //Get the types's string representation:
         Glib::ustring schema_type_string;
@@ -84,11 +73,7 @@ FieldTypes::FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connectio
         
         if(!schema_type_string.empty())
         {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-          Gnome::Gda::Value value_gdatype = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_GTYPE, i);
-#else
-          Gnome::Gda::Value value_gdatype = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_GTYPE, i, error);
-#endif
+          const Gnome::Gda::Value value_gdatype = data_model_tables->get_value_at(DATAMODEL_FIELDS_COL_GTYPE, i);
           if(value_gdatype.get_value_type() == G_TYPE_STRING)
           {
             Glib::ustring type_string = value_gdatype.get_string();
@@ -122,21 +107,6 @@ FieldTypes::~FieldTypes()
 {
 }
 
-GType FieldTypes::get_gdavalue_for_schema_type_string(const Glib::ustring& schema_type_string) const
-{
-  // Special case varchar, because we also specialized it in
-  // get_string_name_for_gdavaluetype, so that we can properly convert back
-  // and forth between sql typename and gda type.
-  if(schema_type_string == "varchar")
-    return G_TYPE_STRING;
-
-  type_mapSchemaStringsToGdaTypes::const_iterator iterFind = m_mapSchemaStringsToGdaTypes.find(schema_type_string);
-  if(iterFind == m_mapSchemaStringsToGdaTypes.end())
-    return GDA_TYPE_NULL;
-  else
-    return iterFind->second;
-}
-
 Glib::ustring FieldTypes::get_string_name_for_gdavaluetype(GType field_type) const
 {
   //Special-case gchararray (G_TYPE_STRING) because Gda reports this GType for several 
