@@ -40,9 +40,9 @@ CellRendererDbList::~CellRendererDbList()
 }
 
 
-void CellRendererDbList::set_choices_fixed(const FieldFormatting::type_list_values& list_values)
+void CellRendererDbList::set_choices_fixed(const FieldFormatting::type_list_values& list_values, bool restricted)
 {
-  ComboChoicesWithTreeModel::set_choices_fixed(list_values);
+  ComboChoicesWithTreeModel::set_choices_fixed(list_values, restricted);
 
   Glib::RefPtr<Gtk::TreeModel> model = get_choices_model();
 
@@ -171,10 +171,7 @@ void CellRendererDbList::repack_cells_related(Gtk::CellLayout* combobox)
       //Get the default column, created by set_text_column():
       cell = combobox->get_first_cell();
       if(!cell)
-      {
-        //This is normal, for instance if the item is meant to be hidden.
-        //std::cerr << G_STRFUNC << ": get_first_cell() returned null." << std::endl;
-      }
+        std::cerr << G_STRFUNC << ": get_first_cell() returned null." << std::endl;
       else
       {
         //Unpack and repack it with expand=false instead of expand=true:
@@ -192,16 +189,9 @@ void CellRendererDbList::repack_cells_related(Gtk::CellLayout* combobox)
     {
       //Create the cell:
       cell = create_cell(layout_item, m_table_name, m_document, get_fixed_cell_height(*widget));
-      if(!cell)
-      {
-        std::cerr << G_STRFUNC << ": create_cell() return 0." << std::endl;
-      }
-      else
-      {
-        combobox->pack_start(*cell, true);
+      combobox->pack_start(*cell, true);
 
-        cell_connect_cell_data_func(combobox, cell, i);
-      }
+      cell_connect_cell_data_func(combobox, cell, i);
     }
 
     ++i;
