@@ -22,6 +22,7 @@
 #include <glom/mode_design/layout/dialog_choose_field.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h>
 #include <libglom/utils.h> //For bold_message().
+#include <libglom/db_utils.h>
 #include <glom/utils_ui.h> //For show_ok_dialog().
 
 //#include <libgnome/gnome-i18n.h>
@@ -56,9 +57,13 @@ Dialog_Layout_List_Related::Dialog_Layout_List_Related(BaseObjectType* cobject,
   m_box_related_navigation->show();
   m_hbox_rows_count->show();
   
-  m_spinbutton_rows_count->set_range(0, 100); //Otherwise only 0 would be allowed.
-  m_spinbutton_rows_count->set_increments(1, 10); //Otherwise the buttons do nothing.
-  m_spinbutton_rows_count->signal_value_changed().connect(
+  m_spinbutton_rows_count_min->set_range(0, 100); //Otherwise only 0 would be allowed.
+  m_spinbutton_rows_count_min->set_increments(1, 10); //Otherwise the buttons do nothing.
+  m_spinbutton_rows_count_min->signal_value_changed().connect(
+    sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_spinbutton_changed));
+  m_spinbutton_rows_count_max->set_range(0, 100); //Otherwise only 0 would be allowed.
+  m_spinbutton_rows_count_max->set_increments(1, 10); //Otherwise the buttons do nothing.
+  m_spinbutton_rows_count_max->signal_value_changed().connect(
     sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_spinbutton_changed));
 
   builder->get_widget_derived("combo_relationship_name", m_combo_relationship);
@@ -129,8 +134,12 @@ void Dialog_Layout_List_Related::set_document(const Glib::ustring& layout_name,
     m_portal = glom_sharedptr_clone(portal);
   else
     m_portal = sharedptr<LayoutItem_Portal>::create(); //The rest of the class assumes that this is not null.
-    
-  m_spinbutton_rows_count->set_value( m_portal->get_rows_count() );
+
+  gulong rows_count_min = 0;
+  gulong rows_count_max = 0;
+  m_portal->get_rows_count(rows_count_min, rows_count_max);
+  m_spinbutton_rows_count_min->set_value(rows_count_min);
+  m_spinbutton_rows_count_max->set_value(rows_count_max);
 
   type_vecConstLayoutFields empty_fields; //Just to satisfy the base class.
   Dialog_Layout::set_document(layout_name, layout_platform, document, actual_from_table, empty_fields);
@@ -354,7 +363,9 @@ void Dialog_Layout_List_Related::save_to_document()
       m_portal->set_navigation_type(LayoutItem_Portal::NAVIGATION_NONE);
     }
     
-    m_portal->set_rows_count( m_spinbutton_rows_count->get_value() );
+    m_portal->set_rows_count(
+      m_spinbutton_rows_count_min->get_value(),
+      m_spinbutton_rows_count_max->get_value());
     
     if(m_for_print_layout)
     {
@@ -387,8 +398,8 @@ void Dialog_Layout_List_Related::on_combo_relationship_changed()
   //The relationship's to field may not be a unique field, because that would
   //prevent the portal from having multiple records.
   sharedptr<Field> to_key_field =
-    get_fields_for_table_one_field(relationship->get_to_table(),
-      relationship->get_to_field());
+    DbUtils::get_fields_for_table_one_field(get_document(), 
+      relationship->get_to_table(), relationship->get_to_field());
   bool relationship_invalid = false;
   if(!to_key_field)
   {
