@@ -144,9 +144,7 @@ sharedptr<PrintLayout> Canvas_PrintLayout::get_print_layout()
 /*
 Glib::RefPtr<CanvasLayoutItem> Canvas_PrintLayout::create_canvas_item(const sharedptr<LayoutItem>& item)
 {
-  Glib::RefPtr<CanvasLayoutItem> result = CanvasLayoutItem::create();
-  //TODO: Add to the canvas.
-  result->set_layout_item(item);
+  Glib::RefPtr<CanvasLayoutItem> result = CanvasLayoutItem::create(item);
 
   return result;
 }
@@ -169,22 +167,15 @@ void Canvas_PrintLayout::add_layout_group_children(const sharedptr<LayoutGroup>&
     }
     else
     {
-      create_canvas_layout_item_and_add(item);
+      Glib::RefPtr<CanvasLayoutItem> canvas_item = CanvasLayoutItem::create(item);
+      if(canvas_item && canvas_item->get_child()) //get_child() returns null if the layout item was not handled.
+        add_canvas_layout_item(canvas_item);
     }
   }
 
   m_modified = true;
 }
 
-void Canvas_PrintLayout::create_canvas_layout_item_and_add(const sharedptr<LayoutItem>& layout_item)
-{
-  Glib::RefPtr<CanvasLayoutItem> canvas_item = CanvasLayoutItem::create();
-  add_canvas_layout_item(canvas_item);
-  canvas_item->set_layout_item(layout_item);
-  
-  canvas_item->set_outline_visible(m_outline_visibility);
-}
-
 void Canvas_PrintLayout::add_canvas_layout_item(const Glib::RefPtr<CanvasLayoutItem>& item)
 {
   if(!item)
@@ -202,8 +193,7 @@ void Canvas_PrintLayout::add_canvas_layout_item(const Glib::RefPtr<CanvasLayoutI
       item) );
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
-   if(item->get_child())
-     item->set_outline_visible(m_outline_visibility);
+   item->set_outline_visible(m_outline_visibility);
 
    fill_with_data_system_preferences(item, get_document());
 }
@@ -223,7 +213,9 @@ void Canvas_PrintLayout::add_layout_group(const sharedptr<LayoutGroup>& group, b
   //Add the group item:
   if(!is_top_level)
   {
-    create_canvas_layout_item_and_add(group);
+    Glib::RefPtr<CanvasLayoutItem> canvas_item = CanvasLayoutItem::create(group);
+    if(canvas_item)
+      add_canvas_layout_item(canvas_item);
   }
 
   //Add the group's children.
@@ -717,14 +709,6 @@ guint Canvas_PrintLayout::get_page_count() const
 
 void Canvas_PrintLayout::fill_with_data(const FoundSet& found_set, bool avoid_page_margins)
 {
-  if(found_set.m_where_clause.empty())
-  {
-    //This might help a developer/debugger:
-    //This is not an error.
-    std::cout << G_STRFUNC << ": Not attempting to show real data because the where_clause is empty, maybe because there are no records in the database yet." << std::endl;
-    return;
-  }
-  
   fill_with_data(m_items_group, found_set, avoid_page_margins);
 }
 
@@ -811,7 +795,9 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
         sharedptr<const Relationship> relationship = layoutitem_portal->get_relationship();
         if(relationship)
         {
-          const sharedptr<Field> from_field = get_fields_for_table_one_field(relationship->get_from_table(), relationship->get_from_field());
+          const Document* document = get_document();
+          const sharedptr<Field> from_field = DbUtils::get_fields_for_table_one_field(document,
+            relationship->get_from_table(), relationship->get_from_field());
           const Gnome::Gda::Value from_key_value = get_field_value_in_database(from_field, found_set, 0 /* TODO: window */);
           fill_with_data_portal(canvas_item, from_key_value);
         }
