@@ -21,10 +21,10 @@
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 #include <glom/utils_ui.h>
+#include <glom/application.h>
 #include <libglom/connectionpool.h>
 #include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
 #include <libglom/data_structure/glomconversions.h>
-#include <libglom/utils.h>
 
 #include <libglom/data_structure/layout/layoutitem_image.h> // For GLOM_IMAGE_FORMAT
 #include <gdkmm/pixbufloader.h>
@@ -365,7 +365,7 @@ int Utils::get_suitable_field_width_for_widget(Gtk::Widget& widget, const shared
   if(or_title)
   {
     //Make sure that there's enough space for the title too.
-    const int title_width = get_width_for_text(widget, field_layout->get_title());
+    const int title_width = get_width_for_text(widget, item_get_title(field_layout));
     if(title_width > result)
       result = title_width;
   }
@@ -534,16 +534,4 @@ std::string Utils::get_icon_path(const Glib::ustring& filename)
 #endif
 }
 
-bool Utils::script_check_for_pygtk2_with_warning(const Glib::ustring& script, Gtk::Window* parent_window)
-{
-  if(!Utils::script_check_for_pygtk2(script))
-  {
-    Utils::show_ok_dialog(_("Script Uses PyGTK 2"),
-      _("Glom cannot run this script because it uses pygtk 2, but Glom uses GTK+ 3, and attempting to use pygtk 2 would cause Glom to crash."), parent_window, Gtk::MESSAGE_ERROR);
-    return false;
-  }
-
-  return true;
-}
-
 } //namespace Glom
